@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# copyright 2016-2021 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2016-2022 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -28,7 +28,16 @@ from cubicweb import ConfigurationError
 from cubicweb.predicates import is_instance
 from cubicweb.server.hook import Hook, DataOperationMixIn, Operation
 
-from cw_celerytask_helpers.filelogger import flush_task_logs
+from cw_celerytask_helpers import fileutils
+# CloudWatch and S3 dependencies are optional
+try:
+    from cw_celerytask_helpers import cloudwatchutils
+except ImportError:
+    cloudwatchutils = None
+try:
+    from cw_celerytask_helpers import s3utils
+except ImportError:
+    s3utils = None
 
 
 class DeleteCeleryTaskOp(DataOperationMixIn, Operation):
@@ -39,7 +48,12 @@ class DeleteCeleryTaskOp(DataOperationMixIn, Operation):
             celery.task.control.revoke(list(tasks), terminate=True,
                                        signal='SIGKILL')
         for task_id in tasks:
-            flush_task_logs(task_id)
+            for utils in [fileutils, cloudwatchutils, s3utils]:
+                if utils:
+                    try:
+                        utils.flush_task_logs(task_id)
+                    except Exception:
+                        pass
 
 
 class CeleryTaskDeletedHook(Hook):
