@@ -1,5 +1,5 @@
 # coding: utf-8
-# copyright 2016-2021 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2016-2022 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -326,8 +326,8 @@ class SegfaultTC(BaseCeleryTaskTC):
             self.wait_async_task(cnx, task.task_id, timeout=15)
             wf = cnx.entity_from_eid(task.eid).cw_adapt_to('IWorkflowable')
             self.assertEqual(wf.state, 'failed')
-            self.assertEqual(wf.latest_trinfo().comment, (
-                'Worker exited prematurely: signal 11 (SIGSEGV).'))
+            self.assertIn('Worker exited prematurely: signal 11 (SIGSEGV)',
+                          wf.latest_trinfo().comment)
 
 
 if __name__ == '__main__':
